@@ -1,5 +1,5 @@
 package POE::Component::SmokeBox::Recent::HTTP;
-$POE::Component::SmokeBox::Recent::HTTP::VERSION = '1.50';
+$POE::Component::SmokeBox::Recent::HTTP::VERSION = '1.52';
 #ABSTRACT: an extremely minimal HTTP client
 
 use strict;
@@ -119,7 +119,7 @@ sub _connect {
 
 sub _web_connected {
   my $self = $_[OBJECT];
-  my $req = HTTP::Request->new( GET => $self->{uri}->path );
+  my $req = HTTP::Request->new( GET => $self->{uri}->path_query );
   $req->protocol( 'HTTP/1.1' );
   $req->header( 'Host', $self->{address} . ( $self->{port} ne '80' ? ":$self->{port}" : '' ) );
   $req->user_agent( sprintf( 'POE-Component-SmokeBox-Recent-HTTP/%s (perl; N; POE; en; rv:%f)', $POE::Component::SmokeBox::Recent::HTTP::VERSION, $POE::Component::SmokeBox::Recent::HTTP::VERSION ) );
@@ -190,7 +190,7 @@ POE::Component::SmokeBox::Recent::HTTP - an extremely minimal HTTP client
 
 =head1 VERSION
 
-version 1.50
+version 1.52
 
 =head1 SYNOPSIS
 
@@ -291,7 +291,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Chris Williams.
+This software is copyright (c) 2020 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
